@@ -4,11 +4,11 @@ use strict;
 use warnings;
 use 5.010;
 
-use parent 'App::Slackeria::Plugin::Base';
+use parent 'App::Slackeria::Plugin';
 
 use CPANPLUS;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 sub new {
 	my ( $obj, %conf ) = @_;
@@ -47,7 +47,7 @@ In F<slackeria/config>
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 DESCRIPTION
 
